# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class ItemLookupServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_items_by_id_externalidinfos(self, id, **kwargs):  # noqa: E501
        """Gets external id infos for an item  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_by_id_externalidinfos(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: list[ExternalIdInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_items_by_id_externalidinfos_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_items_by_id_externalidinfos_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_items_by_id_externalidinfos_with_http_info(self, id, **kwargs):  # noqa: E501
        """Gets external id infos for an item  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_by_id_externalidinfos_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Item Id (required)
        :return: list[ExternalIdInfo]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_items_by_id_externalidinfos" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_items_by_id_externalidinfos`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/{Id}/ExternalIdInfos', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ExternalIdInfo]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_items_remotesearch_image(self, image_url, provider_name, **kwargs):  # noqa: E501
        """Gets a remote image  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_remotesearch_image(image_url, provider_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_url: The image url (required)
        :param str provider_name: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_items_remotesearch_image_with_http_info(image_url, provider_name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_items_remotesearch_image_with_http_info(image_url, provider_name, **kwargs)  # noqa: E501
            return data

    def get_items_remotesearch_image_with_http_info(self, image_url, provider_name, **kwargs):  # noqa: E501
        """Gets a remote image  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_items_remotesearch_image_with_http_info(image_url, provider_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str image_url: The image url (required)
        :param str provider_name: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['image_url', 'provider_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_items_remotesearch_image" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'image_url' is set
        if ('image_url' not in params or
                params['image_url'] is None):
            raise ValueError("Missing the required parameter `image_url` when calling `get_items_remotesearch_image`")  # noqa: E501
        # verify the required parameter 'provider_name' is set
        if ('provider_name' not in params or
                params['provider_name'] is None):
            raise ValueError("Missing the required parameter `provider_name` when calling `get_items_remotesearch_image`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'image_url' in params:
            query_params.append(('ImageUrl', params['image_url']))  # noqa: E501
        if 'provider_name' in params:
            query_params.append(('ProviderName', params['provider_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Image', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_metadata_reset(self, item_ids, **kwargs):  # noqa: E501
        """Resets metadata for one or more items  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_metadata_reset(item_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_ids: The item ids (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_metadata_reset_with_http_info(item_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_metadata_reset_with_http_info(item_ids, **kwargs)  # noqa: E501
            return data

    def post_items_metadata_reset_with_http_info(self, item_ids, **kwargs):  # noqa: E501
        """Resets metadata for one or more items  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_metadata_reset_with_http_info(item_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str item_ids: The item ids (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['item_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_metadata_reset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'item_ids' is set
        if ('item_ids' not in params or
                params['item_ids'] is None):
            raise ValueError("Missing the required parameter `item_ids` when calling `post_items_metadata_reset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'item_ids' in params:
            query_params.append(('ItemIds', params['item_ids']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/Metadata/Reset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_apply_by_id(self, body, id, **kwargs):  # noqa: E501
        """Applies search criteria to an item and refreshes metadata  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_apply_by_id(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchResult body: RemoteSearchResult:  (required)
        :param str id: The item id (required)
        :param bool replace_all_images: Whether or not to replace all images
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_apply_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_apply_by_id_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_apply_by_id_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Applies search criteria to an item and refreshes metadata  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_apply_by_id_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchResult body: RemoteSearchResult:  (required)
        :param str id: The item id (required)
        :param bool replace_all_images: Whether or not to replace all images
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id', 'replace_all_images']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_apply_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_apply_by_id`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `post_items_remotesearch_apply_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['Id'] = params['id']  # noqa: E501

        query_params = []
        if 'replace_all_images' in params:
            query_params.append(('ReplaceAllImages', params['replace_all_images']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Apply/{Id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_book(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_book  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_book(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryBookInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_book_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_book_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_book_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_book  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_book_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryBookInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_book" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_book`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Book', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_boxset(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_boxset  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_boxset(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryItemLookupInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_boxset_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_boxset_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_boxset_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_boxset  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_boxset_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryItemLookupInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_boxset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_boxset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/BoxSet', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_game(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_game  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_game(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryGameInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_game_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_game_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_game_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_game  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_game_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryGameInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_game" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_game`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Game', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_movie(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_movie  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_movie(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryMovieInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_movie_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_movie_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_movie_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_movie  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_movie_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryMovieInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_movie" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_movie`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Movie', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_musicalbum(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicalbum  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicalbum(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryAlbumInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_musicalbum_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_musicalbum_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_musicalbum_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicalbum  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicalbum_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryAlbumInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_musicalbum" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_musicalbum`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/MusicAlbum', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_musicartist(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicartist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicartist(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryArtistInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_musicartist_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_musicartist_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_musicartist_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicartist  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicartist_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryArtistInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_musicartist" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_musicartist`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/MusicArtist', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_musicvideo(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicvideo  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicvideo(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryMusicVideoInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_musicvideo_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_musicvideo_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_musicvideo_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_musicvideo  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_musicvideo_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryMusicVideoInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_musicvideo" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_musicvideo`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/MusicVideo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_person(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_person  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_person(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryPersonLookupInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_person_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_person_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_person_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_person  # noqa: E501

        Requires authentication as administrator  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_person_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryPersonLookupInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_person" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_person`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Person', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_series(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_series  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_series(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQuerySeriesInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_series_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_series_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_series_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_series  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_series_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQuerySeriesInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_series" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_series`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Series', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def post_items_remotesearch_trailer(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_trailer  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_trailer(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryTrailerInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.post_items_remotesearch_trailer_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.post_items_remotesearch_trailer_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def post_items_remotesearch_trailer_with_http_info(self, body, **kwargs):  # noqa: E501
        """post_items_remotesearch_trailer  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.post_items_remotesearch_trailer_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param RemoteSearchQueryTrailerInfo body: RemoteSearchQuery`1:  (required)
        :return: list[RemoteSearchResult]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_items_remotesearch_trailer" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_items_remotesearch_trailer`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Items/RemoteSearch/Trailer', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[RemoteSearchResult]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from emby_client.api_client import ApiClient


class StudiosServiceApi(object):
    """NOTE: This class is auto generated.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_studios(self, **kwargs):  # noqa: E501
        """Gets all studios from a given item, folder, or the entire library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_studios(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str artist_type: Artist or AlbumArtist
        :param str max_official_rating: Optional filter by maximum official rating (PG, PG-13, TV-MA, etc).
        :param bool has_theme_song: Optional filter by items with theme songs.
        :param bool has_theme_video: Optional filter by items with theme videos.
        :param bool has_subtitles: Optional filter by items with subtitles.
        :param bool has_special_feature: Optional filter by items with special features.
        :param bool has_trailer: Optional filter by items with trailers.
        :param str adjacent_to: Optional. Return items that are siblings of a supplied item.
        :param int min_index_number: Optional filter by minimum index number.
        :param str min_start_date: Optional. The minimum premiere date. Format = ISO
        :param str max_start_date: Optional. The maximum premiere date. Format = ISO
        :param str min_end_date: Optional. The minimum premiere date. Format = ISO
        :param str max_end_date: Optional. The maximum premiere date. Format = ISO
        :param int min_players: Optional filter by minimum number of game players.
        :param int max_players: Optional filter by maximum number of game players.
        :param int parent_index_number: Optional filter by parent index number.
        :param bool has_parental_rating: Optional filter by items that have or do not have a parental rating
        :param bool is_hd: Optional filter by items that are HD or not.
        :param bool is_unaired: Optional filter by items that are unaired episodes or not.
        :param float min_community_rating: Optional filter by minimum community rating.
        :param float min_critic_rating: Optional filter by minimum critic rating.
        :param int aired_during_season: Gets all episodes that aired during a season, including specials.
        :param str min_premiere_date: Optional. The minimum premiere date. Format = ISO
        :param str min_date_last_saved: Optional. The minimum premiere date. Format = ISO
        :param str min_date_last_saved_for_user: Optional. The minimum premiere date. Format = ISO
        :param str max_premiere_date: Optional. The maximum premiere date. Format = ISO
        :param bool has_overview: Optional filter by items that have an overview or not.
        :param bool has_imdb_id: Optional filter by items that have an imdb id or not.
        :param bool has_tmdb_id: Optional filter by items that have a tmdb id or not.
        :param bool has_tvdb_id: Optional filter by items that have a tvdb id or not.
        :param str exclude_item_ids: Optional. If specified, results will be filtered by exxcluding item ids. This allows multiple, comma delimeted.
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param bool recursive: When searching within folders, this determines whether or not the search will be recursive. true/false
        :param str search_term: Enter a search term to perform a search request
        :param str sort_order: Sort Order - Ascending,Descending
        :param str parent_id: Specify this to localize the search to a specific item or folder. Omit to use the root
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines
        :param str exclude_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str include_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str any_provider_id_equals: Optional. If specified, result will be filtered to contain only items which match at least one of the specified IDs. Each provider ID must be in the form 'prov.id', e.g. 'imdb.tt123456'. This allows multiple, comma delimeted value pairs.
        :param str filters: Optional. Specify additional filters to apply. This allows multiple, comma delimeted. Options: IsFolder, IsNotFolder, IsUnplayed, IsPlayed, IsFavorite, IsResumable, Likes, Dislikes
        :param bool is_favorite: Optional filter by items that are marked as favorite, or not.
        :param bool is_movie: Optional filter for movies.
        :param bool is_series: Optional filter for series.
        :param bool is_folder: Optional filter for folders.
        :param bool is_news: Optional filter for news.
        :param bool is_kids: Optional filter for kids.
        :param bool is_sports: Optional filter for sports.
        :param bool is_new: Optional filter for IsNew.
        :param bool is_premiere: Optional filter for IsPremiere.
        :param bool is_new_or_premiere: Optional filter for IsNewOrPremiere.
        :param bool is_repeat: Optional filter for IsRepeat.
        :param bool project_to_media: ProjectToMedia
        :param str media_types: Optional filter by MediaType. Allows multiple, comma delimited.
        :param str image_types: Optional. If specified, results will be filtered based on those containing image types. This allows multiple, comma delimited.
        :param str sort_by: Optional. Specify one or more sort orders, comma delimeted. Options: Album, AlbumArtist, Artist, Budget, CommunityRating, CriticRating, DateCreated, DatePlayed, PlayCount, PremiereDate, ProductionYear, SortName, Random, Revenue, Runtime
        :param bool is_played: Optional filter by items that are played, or not.
        :param str genres: Optional. If specified, results will be filtered based on genre. This allows multiple, pipe delimeted.
        :param str official_ratings: Optional. If specified, results will be filtered based on OfficialRating. This allows multiple, pipe delimeted.
        :param str tags: Optional. If specified, results will be filtered based on tag. This allows multiple, pipe delimeted.
        :param str exclude_tags: Optional. If specified, results will be filtered based on tag. This allows multiple, pipe delimeted.
        :param str years: Optional. If specified, results will be filtered based on production year. This allows multiple, comma delimeted.
        :param bool enable_images: Optional, include image information in output
        :param bool enable_user_data: Optional, include user data
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param str person: Optional. If specified, results will be filtered to include only those containing the specified person.
        :param str person_ids: Optional. If specified, results will be filtered to include only those containing the specified person.
        :param str person_types: Optional. If specified, along with Person, results will be filtered to include only those containing the specified person and PersonType. Allows multiple, comma-delimited
        :param str studios: Optional. If specified, results will be filtered based on studio. This allows multiple, pipe delimeted.
        :param str studio_ids: Optional. If specified, results will be filtered based on studio. This allows multiple, pipe delimeted.
        :param str artists: Optional. If specified, results will be filtered based on artist. This allows multiple, pipe delimeted.
        :param str artist_ids: Optional. If specified, results will be filtered based on artist. This allows multiple, pipe delimeted.
        :param str albums: Optional. If specified, results will be filtered based on album. This allows multiple, pipe delimeted.
        :param str ids: Optional. If specific items are needed, specify a list of item id's to retrieve. This allows multiple, comma delimited.
        :param str video_types: Optional filter by VideoType (videofile, dvd, bluray, iso). Allows multiple, comma delimeted.
        :param str containers: Optional filter by Container. Allows multiple, comma delimeted.
        :param str audio_codecs: Optional filter by AudioCodec. Allows multiple, comma delimeted.
        :param str audio_layouts: Optional filter by AudioLayout. Allows multiple, comma delimeted.
        :param str video_codecs: Optional filter by VideoCodec. Allows multiple, comma delimeted.
        :param str extended_video_types: Optional filter by ExtendedVideoType. Allows multiple, comma delimeted.
        :param str subtitle_codecs: Optional filter by SubtitleCodec. Allows multiple, comma delimeted.
        :param str path: Optional filter by Path.
        :param str user_id: User Id
        :param str min_official_rating: Optional filter by minimum official rating (PG, PG-13, TV-MA, etc).
        :param bool is_locked: Optional filter by items that are locked.
        :param bool is_place_holder: Optional filter by items that are placeholders
        :param bool has_official_rating: Optional filter by items that have official ratings
        :param bool group_items_into_collections: Whether or not to hide items behind their boxsets.
        :param bool is3_d: Optional filter by items that are 3D, or not.
        :param str series_status: Optional filter by Series Status. Allows multiple, comma delimeted.
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str artist_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str album_artist_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str name_starts_with: Optional filter by items whose name is sorted equally than a given input string.
        :param str name_less_than: Optional filter by items whose name is equally or lesser than a given input string.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_studios_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_studios_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_studios_with_http_info(self, **kwargs):  # noqa: E501
        """Gets all studios from a given item, folder, or the entire library  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_studios_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str artist_type: Artist or AlbumArtist
        :param str max_official_rating: Optional filter by maximum official rating (PG, PG-13, TV-MA, etc).
        :param bool has_theme_song: Optional filter by items with theme songs.
        :param bool has_theme_video: Optional filter by items with theme videos.
        :param bool has_subtitles: Optional filter by items with subtitles.
        :param bool has_special_feature: Optional filter by items with special features.
        :param bool has_trailer: Optional filter by items with trailers.
        :param str adjacent_to: Optional. Return items that are siblings of a supplied item.
        :param int min_index_number: Optional filter by minimum index number.
        :param str min_start_date: Optional. The minimum premiere date. Format = ISO
        :param str max_start_date: Optional. The maximum premiere date. Format = ISO
        :param str min_end_date: Optional. The minimum premiere date. Format = ISO
        :param str max_end_date: Optional. The maximum premiere date. Format = ISO
        :param int min_players: Optional filter by minimum number of game players.
        :param int max_players: Optional filter by maximum number of game players.
        :param int parent_index_number: Optional filter by parent index number.
        :param bool has_parental_rating: Optional filter by items that have or do not have a parental rating
        :param bool is_hd: Optional filter by items that are HD or not.
        :param bool is_unaired: Optional filter by items that are unaired episodes or not.
        :param float min_community_rating: Optional filter by minimum community rating.
        :param float min_critic_rating: Optional filter by minimum critic rating.
        :param int aired_during_season: Gets all episodes that aired during a season, including specials.
        :param str min_premiere_date: Optional. The minimum premiere date. Format = ISO
        :param str min_date_last_saved: Optional. The minimum premiere date. Format = ISO
        :param str min_date_last_saved_for_user: Optional. The minimum premiere date. Format = ISO
        :param str max_premiere_date: Optional. The maximum premiere date. Format = ISO
        :param bool has_overview: Optional filter by items that have an overview or not.
        :param bool has_imdb_id: Optional filter by items that have an imdb id or not.
        :param bool has_tmdb_id: Optional filter by items that have a tmdb id or not.
        :param bool has_tvdb_id: Optional filter by items that have a tvdb id or not.
        :param str exclude_item_ids: Optional. If specified, results will be filtered by exxcluding item ids. This allows multiple, comma delimeted.
        :param int start_index: Optional. The record index to start at. All items with a lower index will be dropped from the results.
        :param int limit: Optional. The maximum number of records to return
        :param bool recursive: When searching within folders, this determines whether or not the search will be recursive. true/false
        :param str search_term: Enter a search term to perform a search request
        :param str sort_order: Sort Order - Ascending,Descending
        :param str parent_id: Specify this to localize the search to a specific item or folder. Omit to use the root
        :param str fields: Optional. Specify additional fields of information to return in the output. This allows multiple, comma delimeted. Options: Budget, Chapters, DateCreated, Genres, HomePageUrl, IndexOptions, MediaStreams, Overview, ParentId, Path, People, ProviderIds, PrimaryImageAspectRatio, Revenue, SortName, Studios, Taglines
        :param str exclude_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str include_item_types: Optional. If specified, results will be filtered based on item type. This allows multiple, comma delimeted.
        :param str any_provider_id_equals: Optional. If specified, result will be filtered to contain only items which match at least one of the specified IDs. Each provider ID must be in the form 'prov.id', e.g. 'imdb.tt123456'. This allows multiple, comma delimeted value pairs.
        :param str filters: Optional. Specify additional filters to apply. This allows multiple, comma delimeted. Options: IsFolder, IsNotFolder, IsUnplayed, IsPlayed, IsFavorite, IsResumable, Likes, Dislikes
        :param bool is_favorite: Optional filter by items that are marked as favorite, or not.
        :param bool is_movie: Optional filter for movies.
        :param bool is_series: Optional filter for series.
        :param bool is_folder: Optional filter for folders.
        :param bool is_news: Optional filter for news.
        :param bool is_kids: Optional filter for kids.
        :param bool is_sports: Optional filter for sports.
        :param bool is_new: Optional filter for IsNew.
        :param bool is_premiere: Optional filter for IsPremiere.
        :param bool is_new_or_premiere: Optional filter for IsNewOrPremiere.
        :param bool is_repeat: Optional filter for IsRepeat.
        :param bool project_to_media: ProjectToMedia
        :param str media_types: Optional filter by MediaType. Allows multiple, comma delimited.
        :param str image_types: Optional. If specified, results will be filtered based on those containing image types. This allows multiple, comma delimited.
        :param str sort_by: Optional. Specify one or more sort orders, comma delimeted. Options: Album, AlbumArtist, Artist, Budget, CommunityRating, CriticRating, DateCreated, DatePlayed, PlayCount, PremiereDate, ProductionYear, SortName, Random, Revenue, Runtime
        :param bool is_played: Optional filter by items that are played, or not.
        :param str genres: Optional. If specified, results will be filtered based on genre. This allows multiple, pipe delimeted.
        :param str official_ratings: Optional. If specified, results will be filtered based on OfficialRating. This allows multiple, pipe delimeted.
        :param str tags: Optional. If specified, results will be filtered based on tag. This allows multiple, pipe delimeted.
        :param str exclude_tags: Optional. If specified, results will be filtered based on tag. This allows multiple, pipe delimeted.
        :param str years: Optional. If specified, results will be filtered based on production year. This allows multiple, comma delimeted.
        :param bool enable_images: Optional, include image information in output
        :param bool enable_user_data: Optional, include user data
        :param int image_type_limit: Optional, the max number of images to return, per image type
        :param str enable_image_types: Optional. The image types to include in the output.
        :param str person: Optional. If specified, results will be filtered to include only those containing the specified person.
        :param str person_ids: Optional. If specified, results will be filtered to include only those containing the specified person.
        :param str person_types: Optional. If specified, along with Person, results will be filtered to include only those containing the specified person and PersonType. Allows multiple, comma-delimited
        :param str studios: Optional. If specified, results will be filtered based on studio. This allows multiple, pipe delimeted.
        :param str studio_ids: Optional. If specified, results will be filtered based on studio. This allows multiple, pipe delimeted.
        :param str artists: Optional. If specified, results will be filtered based on artist. This allows multiple, pipe delimeted.
        :param str artist_ids: Optional. If specified, results will be filtered based on artist. This allows multiple, pipe delimeted.
        :param str albums: Optional. If specified, results will be filtered based on album. This allows multiple, pipe delimeted.
        :param str ids: Optional. If specific items are needed, specify a list of item id's to retrieve. This allows multiple, comma delimited.
        :param str video_types: Optional filter by VideoType (videofile, dvd, bluray, iso). Allows multiple, comma delimeted.
        :param str containers: Optional filter by Container. Allows multiple, comma delimeted.
        :param str audio_codecs: Optional filter by AudioCodec. Allows multiple, comma delimeted.
        :param str audio_layouts: Optional filter by AudioLayout. Allows multiple, comma delimeted.
        :param str video_codecs: Optional filter by VideoCodec. Allows multiple, comma delimeted.
        :param str extended_video_types: Optional filter by ExtendedVideoType. Allows multiple, comma delimeted.
        :param str subtitle_codecs: Optional filter by SubtitleCodec. Allows multiple, comma delimeted.
        :param str path: Optional filter by Path.
        :param str user_id: User Id
        :param str min_official_rating: Optional filter by minimum official rating (PG, PG-13, TV-MA, etc).
        :param bool is_locked: Optional filter by items that are locked.
        :param bool is_place_holder: Optional filter by items that are placeholders
        :param bool has_official_rating: Optional filter by items that have official ratings
        :param bool group_items_into_collections: Whether or not to hide items behind their boxsets.
        :param bool is3_d: Optional filter by items that are 3D, or not.
        :param str series_status: Optional filter by Series Status. Allows multiple, comma delimeted.
        :param str name_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str artist_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str album_artist_starts_with_or_greater: Optional filter by items whose name is sorted equally or greater than a given input string.
        :param str name_starts_with: Optional filter by items whose name is sorted equally than a given input string.
        :param str name_less_than: Optional filter by items whose name is equally or lesser than a given input string.
        :return: QueryResultBaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['artist_type', 'max_official_rating', 'has_theme_song', 'has_theme_video', 'has_subtitles', 'has_special_feature', 'has_trailer', 'adjacent_to', 'min_index_number', 'min_start_date', 'max_start_date', 'min_end_date', 'max_end_date', 'min_players', 'max_players', 'parent_index_number', 'has_parental_rating', 'is_hd', 'is_unaired', 'min_community_rating', 'min_critic_rating', 'aired_during_season', 'min_premiere_date', 'min_date_last_saved', 'min_date_last_saved_for_user', 'max_premiere_date', 'has_overview', 'has_imdb_id', 'has_tmdb_id', 'has_tvdb_id', 'exclude_item_ids', 'start_index', 'limit', 'recursive', 'search_term', 'sort_order', 'parent_id', 'fields', 'exclude_item_types', 'include_item_types', 'any_provider_id_equals', 'filters', 'is_favorite', 'is_movie', 'is_series', 'is_folder', 'is_news', 'is_kids', 'is_sports', 'is_new', 'is_premiere', 'is_new_or_premiere', 'is_repeat', 'project_to_media', 'media_types', 'image_types', 'sort_by', 'is_played', 'genres', 'official_ratings', 'tags', 'exclude_tags', 'years', 'enable_images', 'enable_user_data', 'image_type_limit', 'enable_image_types', 'person', 'person_ids', 'person_types', 'studios', 'studio_ids', 'artists', 'artist_ids', 'albums', 'ids', 'video_types', 'containers', 'audio_codecs', 'audio_layouts', 'video_codecs', 'extended_video_types', 'subtitle_codecs', 'path', 'user_id', 'min_official_rating', 'is_locked', 'is_place_holder', 'has_official_rating', 'group_items_into_collections', 'is3_d', 'series_status', 'name_starts_with_or_greater', 'artist_starts_with_or_greater', 'album_artist_starts_with_or_greater', 'name_starts_with', 'name_less_than']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_studios" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'artist_type' in params:
            query_params.append(('ArtistType', params['artist_type']))  # noqa: E501
        if 'max_official_rating' in params:
            query_params.append(('MaxOfficialRating', params['max_official_rating']))  # noqa: E501
        if 'has_theme_song' in params:
            query_params.append(('HasThemeSong', params['has_theme_song']))  # noqa: E501
        if 'has_theme_video' in params:
            query_params.append(('HasThemeVideo', params['has_theme_video']))  # noqa: E501
        if 'has_subtitles' in params:
            query_params.append(('HasSubtitles', params['has_subtitles']))  # noqa: E501
        if 'has_special_feature' in params:
            query_params.append(('HasSpecialFeature', params['has_special_feature']))  # noqa: E501
        if 'has_trailer' in params:
            query_params.append(('HasTrailer', params['has_trailer']))  # noqa: E501
        if 'adjacent_to' in params:
            query_params.append(('AdjacentTo', params['adjacent_to']))  # noqa: E501
        if 'min_index_number' in params:
            query_params.append(('MinIndexNumber', params['min_index_number']))  # noqa: E501
        if 'min_start_date' in params:
            query_params.append(('MinStartDate', params['min_start_date']))  # noqa: E501
        if 'max_start_date' in params:
            query_params.append(('MaxStartDate', params['max_start_date']))  # noqa: E501
        if 'min_end_date' in params:
            query_params.append(('MinEndDate', params['min_end_date']))  # noqa: E501
        if 'max_end_date' in params:
            query_params.append(('MaxEndDate', params['max_end_date']))  # noqa: E501
        if 'min_players' in params:
            query_params.append(('MinPlayers', params['min_players']))  # noqa: E501
        if 'max_players' in params:
            query_params.append(('MaxPlayers', params['max_players']))  # noqa: E501
        if 'parent_index_number' in params:
            query_params.append(('ParentIndexNumber', params['parent_index_number']))  # noqa: E501
        if 'has_parental_rating' in params:
            query_params.append(('HasParentalRating', params['has_parental_rating']))  # noqa: E501
        if 'is_hd' in params:
            query_params.append(('IsHD', params['is_hd']))  # noqa: E501
        if 'is_unaired' in params:
            query_params.append(('IsUnaired', params['is_unaired']))  # noqa: E501
        if 'min_community_rating' in params:
            query_params.append(('MinCommunityRating', params['min_community_rating']))  # noqa: E501
        if 'min_critic_rating' in params:
            query_params.append(('MinCriticRating', params['min_critic_rating']))  # noqa: E501
        if 'aired_during_season' in params:
            query_params.append(('AiredDuringSeason', params['aired_during_season']))  # noqa: E501
        if 'min_premiere_date' in params:
            query_params.append(('MinPremiereDate', params['min_premiere_date']))  # noqa: E501
        if 'min_date_last_saved' in params:
            query_params.append(('MinDateLastSaved', params['min_date_last_saved']))  # noqa: E501
        if 'min_date_last_saved_for_user' in params:
            query_params.append(('MinDateLastSavedForUser', params['min_date_last_saved_for_user']))  # noqa: E501
        if 'max_premiere_date' in params:
            query_params.append(('MaxPremiereDate', params['max_premiere_date']))  # noqa: E501
        if 'has_overview' in params:
            query_params.append(('HasOverview', params['has_overview']))  # noqa: E501
        if 'has_imdb_id' in params:
            query_params.append(('HasImdbId', params['has_imdb_id']))  # noqa: E501
        if 'has_tmdb_id' in params:
            query_params.append(('HasTmdbId', params['has_tmdb_id']))  # noqa: E501
        if 'has_tvdb_id' in params:
            query_params.append(('HasTvdbId', params['has_tvdb_id']))  # noqa: E501
        if 'exclude_item_ids' in params:
            query_params.append(('ExcludeItemIds', params['exclude_item_ids']))  # noqa: E501
        if 'start_index' in params:
            query_params.append(('StartIndex', params['start_index']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('Limit', params['limit']))  # noqa: E501
        if 'recursive' in params:
            query_params.append(('Recursive', params['recursive']))  # noqa: E501
        if 'search_term' in params:
            query_params.append(('SearchTerm', params['search_term']))  # noqa: E501
        if 'sort_order' in params:
            query_params.append(('SortOrder', params['sort_order']))  # noqa: E501
        if 'parent_id' in params:
            query_params.append(('ParentId', params['parent_id']))  # noqa: E501
        if 'fields' in params:
            query_params.append(('Fields', params['fields']))  # noqa: E501
        if 'exclude_item_types' in params:
            query_params.append(('ExcludeItemTypes', params['exclude_item_types']))  # noqa: E501
        if 'include_item_types' in params:
            query_params.append(('IncludeItemTypes', params['include_item_types']))  # noqa: E501
        if 'any_provider_id_equals' in params:
            query_params.append(('AnyProviderIdEquals', params['any_provider_id_equals']))  # noqa: E501
        if 'filters' in params:
            query_params.append(('Filters', params['filters']))  # noqa: E501
        if 'is_favorite' in params:
            query_params.append(('IsFavorite', params['is_favorite']))  # noqa: E501
        if 'is_movie' in params:
            query_params.append(('IsMovie', params['is_movie']))  # noqa: E501
        if 'is_series' in params:
            query_params.append(('IsSeries', params['is_series']))  # noqa: E501
        if 'is_folder' in params:
            query_params.append(('IsFolder', params['is_folder']))  # noqa: E501
        if 'is_news' in params:
            query_params.append(('IsNews', params['is_news']))  # noqa: E501
        if 'is_kids' in params:
            query_params.append(('IsKids', params['is_kids']))  # noqa: E501
        if 'is_sports' in params:
            query_params.append(('IsSports', params['is_sports']))  # noqa: E501
        if 'is_new' in params:
            query_params.append(('IsNew', params['is_new']))  # noqa: E501
        if 'is_premiere' in params:
            query_params.append(('IsPremiere', params['is_premiere']))  # noqa: E501
        if 'is_new_or_premiere' in params:
            query_params.append(('IsNewOrPremiere', params['is_new_or_premiere']))  # noqa: E501
        if 'is_repeat' in params:
            query_params.append(('IsRepeat', params['is_repeat']))  # noqa: E501
        if 'project_to_media' in params:
            query_params.append(('ProjectToMedia', params['project_to_media']))  # noqa: E501
        if 'media_types' in params:
            query_params.append(('MediaTypes', params['media_types']))  # noqa: E501
        if 'image_types' in params:
            query_params.append(('ImageTypes', params['image_types']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('SortBy', params['sort_by']))  # noqa: E501
        if 'is_played' in params:
            query_params.append(('IsPlayed', params['is_played']))  # noqa: E501
        if 'genres' in params:
            query_params.append(('Genres', params['genres']))  # noqa: E501
        if 'official_ratings' in params:
            query_params.append(('OfficialRatings', params['official_ratings']))  # noqa: E501
        if 'tags' in params:
            query_params.append(('Tags', params['tags']))  # noqa: E501
        if 'exclude_tags' in params:
            query_params.append(('ExcludeTags', params['exclude_tags']))  # noqa: E501
        if 'years' in params:
            query_params.append(('Years', params['years']))  # noqa: E501
        if 'enable_images' in params:
            query_params.append(('EnableImages', params['enable_images']))  # noqa: E501
        if 'enable_user_data' in params:
            query_params.append(('EnableUserData', params['enable_user_data']))  # noqa: E501
        if 'image_type_limit' in params:
            query_params.append(('ImageTypeLimit', params['image_type_limit']))  # noqa: E501
        if 'enable_image_types' in params:
            query_params.append(('EnableImageTypes', params['enable_image_types']))  # noqa: E501
        if 'person' in params:
            query_params.append(('Person', params['person']))  # noqa: E501
        if 'person_ids' in params:
            query_params.append(('PersonIds', params['person_ids']))  # noqa: E501
        if 'person_types' in params:
            query_params.append(('PersonTypes', params['person_types']))  # noqa: E501
        if 'studios' in params:
            query_params.append(('Studios', params['studios']))  # noqa: E501
        if 'studio_ids' in params:
            query_params.append(('StudioIds', params['studio_ids']))  # noqa: E501
        if 'artists' in params:
            query_params.append(('Artists', params['artists']))  # noqa: E501
        if 'artist_ids' in params:
            query_params.append(('ArtistIds', params['artist_ids']))  # noqa: E501
        if 'albums' in params:
            query_params.append(('Albums', params['albums']))  # noqa: E501
        if 'ids' in params:
            query_params.append(('Ids', params['ids']))  # noqa: E501
        if 'video_types' in params:
            query_params.append(('VideoTypes', params['video_types']))  # noqa: E501
        if 'containers' in params:
            query_params.append(('Containers', params['containers']))  # noqa: E501
        if 'audio_codecs' in params:
            query_params.append(('AudioCodecs', params['audio_codecs']))  # noqa: E501
        if 'audio_layouts' in params:
            query_params.append(('AudioLayouts', params['audio_layouts']))  # noqa: E501
        if 'video_codecs' in params:
            query_params.append(('VideoCodecs', params['video_codecs']))  # noqa: E501
        if 'extended_video_types' in params:
            query_params.append(('ExtendedVideoTypes', params['extended_video_types']))  # noqa: E501
        if 'subtitle_codecs' in params:
            query_params.append(('SubtitleCodecs', params['subtitle_codecs']))  # noqa: E501
        if 'path' in params:
            query_params.append(('Path', params['path']))  # noqa: E501
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501
        if 'min_official_rating' in params:
            query_params.append(('MinOfficialRating', params['min_official_rating']))  # noqa: E501
        if 'is_locked' in params:
            query_params.append(('IsLocked', params['is_locked']))  # noqa: E501
        if 'is_place_holder' in params:
            query_params.append(('IsPlaceHolder', params['is_place_holder']))  # noqa: E501
        if 'has_official_rating' in params:
            query_params.append(('HasOfficialRating', params['has_official_rating']))  # noqa: E501
        if 'group_items_into_collections' in params:
            query_params.append(('GroupItemsIntoCollections', params['group_items_into_collections']))  # noqa: E501
        if 'is3_d' in params:
            query_params.append(('Is3D', params['is3_d']))  # noqa: E501
        if 'series_status' in params:
            query_params.append(('SeriesStatus', params['series_status']))  # noqa: E501
        if 'name_starts_with_or_greater' in params:
            query_params.append(('NameStartsWithOrGreater', params['name_starts_with_or_greater']))  # noqa: E501
        if 'artist_starts_with_or_greater' in params:
            query_params.append(('ArtistStartsWithOrGreater', params['artist_starts_with_or_greater']))  # noqa: E501
        if 'album_artist_starts_with_or_greater' in params:
            query_params.append(('AlbumArtistStartsWithOrGreater', params['album_artist_starts_with_or_greater']))  # noqa: E501
        if 'name_starts_with' in params:
            query_params.append(('NameStartsWith', params['name_starts_with']))  # noqa: E501
        if 'name_less_than' in params:
            query_params.append(('NameLessThan', params['name_less_than']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Studios', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='QueryResultBaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_studios_by_name(self, name, **kwargs):  # noqa: E501
        """Gets a studio, by name  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_studios_by_name(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The studio name (required)
        :param str user_id: Optional. Filter by user id, and attach user data
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_studios_by_name_with_http_info(name, **kwargs)  # noqa: E501
        else:
            (data) = self.get_studios_by_name_with_http_info(name, **kwargs)  # noqa: E501
            return data

    def get_studios_by_name_with_http_info(self, name, **kwargs):  # noqa: E501
        """Gets a studio, by name  # noqa: E501

        Requires authentication as user  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_studios_by_name_with_http_info(name, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str name: The studio name (required)
        :param str user_id: Optional. Filter by user id, and attach user data
        :return: BaseItemDto
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['name', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_studios_by_name" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'name' is set
        if ('name' not in params or
                params['name'] is None):
            raise ValueError("Missing the required parameter `name` when calling `get_studios_by_name`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'name' in params:
            path_params['Name'] = params['name']  # noqa: E501

        query_params = []
        if 'user_id' in params:
            query_params.append(('UserId', params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = ['apikeyauth', 'embyauth']  # noqa: E501

        return self.api_client.call_api(
            '/Studios/{Name}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BaseItemDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Emby Server REST API (BETA)
"""

import pprint
import re  # noqa: F401

import six

class UserPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_administrator': 'bool',
        'is_hidden': 'bool',
        'is_hidden_remotely': 'bool',
        'is_hidden_from_unused_devices': 'bool',
        'is_disabled': 'bool',
        'locked_out_date': 'int',
        'max_parental_rating': 'int',
        'allow_tag_or_rating': 'bool',
        'blocked_tags': 'list[str]',
        'is_tag_blocking_mode_inclusive': 'bool',
        'include_tags': 'list[str]',
        'enable_user_preference_access': 'bool',
        'access_schedules': 'list[AccessSchedule]',
        'block_unrated_items': 'list[UnratedItem]',
        'enable_remote_control_of_other_users': 'bool',
        'enable_shared_device_control': 'bool',
        'enable_remote_access': 'bool',
        'enable_live_tv_management': 'bool',
        'enable_live_tv_access': 'bool',
        'enable_media_playback': 'bool',
        'enable_audio_playback_transcoding': 'bool',
        'enable_video_playback_transcoding': 'bool',
        'enable_playback_remuxing': 'bool',
        'enable_content_deletion': 'bool',
        'restricted_features': 'list[str]',
        'enable_content_deletion_from_folders': 'list[str]',
        'enable_content_downloading': 'bool',
        'enable_subtitle_downloading': 'bool',
        'enable_subtitle_management': 'bool',
        'enable_sync_transcoding': 'bool',
        'enable_media_conversion': 'bool',
        'enabled_channels': 'list[str]',
        'enable_all_channels': 'bool',
        'enabled_folders': 'list[str]',
        'enable_all_folders': 'bool',
        'invalid_login_attempt_count': 'int',
        'enable_public_sharing': 'bool',
        'blocked_media_folders': 'list[str]',
        'remote_client_bitrate_limit': 'int',
        'authentication_provider_id': 'str',
        'excluded_sub_folders': 'list[str]',
        'simultaneous_stream_limit': 'int',
        'enabled_devices': 'list[str]',
        'enable_all_devices': 'bool',
        'allow_camera_upload': 'bool',
        'allow_sharing_personal_items': 'bool'
    }

    attribute_map = {
        'is_administrator': 'IsAdministrator',
        'is_hidden': 'IsHidden',
        'is_hidden_remotely': 'IsHiddenRemotely',
        'is_hidden_from_unused_devices': 'IsHiddenFromUnusedDevices',
        'is_disabled': 'IsDisabled',
        'locked_out_date': 'LockedOutDate',
        'max_parental_rating': 'MaxParentalRating',
        'allow_tag_or_rating': 'AllowTagOrRating',
        'blocked_tags': 'BlockedTags',
        'is_tag_blocking_mode_inclusive': 'IsTagBlockingModeInclusive',
        'include_tags': 'IncludeTags',
        'enable_user_preference_access': 'EnableUserPreferenceAccess',
        'access_schedules': 'AccessSchedules',
        'block_unrated_items': 'BlockUnratedItems',
        'enable_remote_control_of_other_users': 'EnableRemoteControlOfOtherUsers',
        'enable_shared_device_control': 'EnableSharedDeviceControl',
        'enable_remote_access': 'EnableRemoteAccess',
        'enable_live_tv_management': 'EnableLiveTvManagement',
        'enable_live_tv_access': 'EnableLiveTvAccess',
        'enable_media_playback': 'EnableMediaPlayback',
        'enable_audio_playback_transcoding': 'EnableAudioPlaybackTranscoding',
        'enable_video_playback_transcoding': 'EnableVideoPlaybackTranscoding',
        'enable_playback_remuxing': 'EnablePlaybackRemuxing',
        'enable_content_deletion': 'EnableContentDeletion',
        'restricted_features': 'RestrictedFeatures',
        'enable_content_deletion_from_folders': 'EnableContentDeletionFromFolders',
        'enable_content_downloading': 'EnableContentDownloading',
        'enable_subtitle_downloading': 'EnableSubtitleDownloading',
        'enable_subtitle_management': 'EnableSubtitleManagement',
        'enable_sync_transcoding': 'EnableSyncTranscoding',
        'enable_media_conversion': 'EnableMediaConversion',
        'enabled_channels': 'EnabledChannels',
        'enable_all_channels': 'EnableAllChannels',
        'enabled_folders': 'EnabledFolders',
        'enable_all_folders': 'EnableAllFolders',
        'invalid_login_attempt_count': 'InvalidLoginAttemptCount',
        'enable_public_sharing': 'EnablePublicSharing',
        'blocked_media_folders': 'BlockedMediaFolders',
        'remote_client_bitrate_limit': 'RemoteClientBitrateLimit',
        'authentication_provider_id': 'AuthenticationProviderId',
        'excluded_sub_folders': 'ExcludedSubFolders',
        'simultaneous_stream_limit': 'SimultaneousStreamLimit',
        'enabled_devices': 'EnabledDevices',
        'enable_all_devices': 'EnableAllDevices',
        'allow_camera_upload': 'AllowCameraUpload',
        'allow_sharing_personal_items': 'AllowSharingPersonalItems'
    }

    def __init__(self, is_administrator=None, is_hidden=None, is_hidden_remotely=None, is_hidden_from_unused_devices=None, is_disabled=None, locked_out_date=None, max_parental_rating=None, allow_tag_or_rating=None, blocked_tags=None, is_tag_blocking_mode_inclusive=None, include_tags=None, enable_user_preference_access=None, access_schedules=None, block_unrated_items=None, enable_remote_control_of_other_users=None, enable_shared_device_control=None, enable_remote_access=None, enable_live_tv_management=None, enable_live_tv_access=None, enable_media_playback=None, enable_audio_playback_transcoding=None, enable_video_playback_transcoding=None, enable_playback_remuxing=None, enable_content_deletion=None, restricted_features=None, enable_content_deletion_from_folders=None, enable_content_downloading=None, enable_subtitle_downloading=None, enable_subtitle_management=None, enable_sync_transcoding=None, enable_media_conversion=None, enabled_channels=None, enable_all_channels=None, enabled_folders=None, enable_all_folders=None, invalid_login_attempt_count=None, enable_public_sharing=None, blocked_media_folders=None, remote_client_bitrate_limit=None, authentication_provider_id=None, excluded_sub_folders=None, simultaneous_stream_limit=None, enabled_devices=None, enable_all_devices=None, allow_camera_upload=None, allow_sharing_personal_items=None):  # noqa: E501
        """UserPolicy - a model defined in Swagger"""  # noqa: E501
        self._is_administrator = None
        self._is_hidden = None
        self._is_hidden_remotely = None
        self._is_hidden_from_unused_devices = None
        self._is_disabled = None
        self._locked_out_date = None
        self._max_parental_rating = None
        self._allow_tag_or_rating = None
        self._blocked_tags = None
        self._is_tag_blocking_mode_inclusive = None
        self._include_tags = None
        self._enable_user_preference_access = None
        self._access_schedules = None
        self._block_unrated_items = None
        self._enable_remote_control_of_other_users = None
        self._enable_shared_device_control = None
        self._enable_remote_access = None
        self._enable_live_tv_management = None
        self._enable_live_tv_access = None
        self._enable_media_playback = None
        self._enable_audio_playback_transcoding = None
        self._enable_video_playback_transcoding = None
        self._enable_playback_remuxing = None
        self._enable_content_deletion = None
        self._restricted_features = None
        self._enable_content_deletion_from_folders = None
        self._enable_content_downloading = None
        self._enable_subtitle_downloading = None
        self._enable_subtitle_management = None
        self._enable_sync_transcoding = None
        self._enable_media_conversion = None
        self._enabled_channels = None
        self._enable_all_channels = None
        self._enabled_folders = None
        self._enable_all_folders = None
        self._invalid_login_attempt_count = None
        self._enable_public_sharing = None
        self._blocked_media_folders = None
        self._remote_client_bitrate_limit = None
        self._authentication_provider_id = None
        self._excluded_sub_folders = None
        self._simultaneous_stream_limit = None
        self._enabled_devices = None
        self._enable_all_devices = None
        self._allow_camera_upload = None
        self._allow_sharing_personal_items = None
        self.discriminator = None
        if is_administrator is not None:
            self.is_administrator = is_administrator
        if is_hidden is not None:
            self.is_hidden = is_hidden
        if is_hidden_remotely is not None:
            self.is_hidden_remotely = is_hidden_remotely
        if is_hidden_from_unused_devices is not None:
            self.is_hidden_from_unused_devices = is_hidden_from_unused_devices
        if is_disabled is not None:
            self.is_disabled = is_disabled
        if locked_out_date is not None:
            self.locked_out_date = locked_out_date
        if max_parental_rating is not None:
            self.max_parental_rating = max_parental_rating
        if allow_tag_or_rating is not None:
            self.allow_tag_or_rating = allow_tag_or_rating
        if blocked_tags is not None:
            self.blocked_tags = blocked_tags
        if is_tag_blocking_mode_inclusive is not None:
            self.is_tag_blocking_mode_inclusive = is_tag_blocking_mode_inclusive
        if include_tags is not None:
            self.include_tags = include_tags
        if enable_user_preference_access is not None:
            self.enable_user_preference_access = enable_user_preference_access
        if access_schedules is not None:
            self.access_schedules = access_schedules
        if block_unrated_items is not None:
            self.block_unrated_items = block_unrated_items
        if enable_remote_control_of_other_users is not None:
            self.enable_remote_control_of_other_users = enable_remote_control_of_other_users
        if enable_shared_device_control is not None:
            self.enable_shared_device_control = enable_shared_device_control
        if enable_remote_access is not None:
            self.enable_remote_access = enable_remote_access
        if enable_live_tv_management is not None:
            self.enable_live_tv_management = enable_live_tv_management
        if enable_live_tv_access is not None:
            self.enable_live_tv_access = enable_live_tv_access
        if enable_media_playback is not None:
            self.enable_media_playback = enable_media_playback
        if enable_audio_playback_transcoding is not None:
            self.enable_audio_playback_transcoding = enable_audio_playback_transcoding
        if enable_video_playback_transcoding is not None:
            self.enable_video_playback_transcoding = enable_video_playback_transcoding
        if enable_playback_remuxing is not None:
            self.enable_playback_remuxing = enable_playback_remuxing
        if enable_content_deletion is not None:
            self.enable_content_deletion = enable_content_deletion
        if restricted_features is not None:
            self.restricted_features = restricted_features
        if enable_content_deletion_from_folders is not None:
            self.enable_content_deletion_from_folders = enable_content_deletion_from_folders
        if enable_content_downloading is not None:
            self.enable_content_downloading = enable_content_downloading
        if enable_subtitle_downloading is not None:
            self.enable_subtitle_downloading = enable_subtitle_downloading
        if enable_subtitle_management is not None:
            self.enable_subtitle_management = enable_subtitle_management
        if enable_sync_transcoding is not None:
            self.enable_sync_transcoding = enable_sync_transcoding
        if enable_media_conversion is not None:
            self.enable_media_conversion = enable_media_conversion
        if enabled_channels is not None:
            self.enabled_channels = enabled_channels
        if enable_all_channels is not None:
            self.enable_all_channels = enable_all_channels
        if enabled_folders is not None:
            self.enabled_folders = enabled_folders
        if enable_all_folders is not None:
            self.enable_all_folders = enable_all_folders
        if invalid_login_attempt_count is not None:
            self.invalid_login_attempt_count = invalid_login_attempt_count
        if enable_public_sharing is not None:
            self.enable_public_sharing = enable_public_sharing
        if blocked_media_folders is not None:
            self.blocked_media_folders = blocked_media_folders
        if remote_client_bitrate_limit is not None:
            self.remote_client_bitrate_limit = remote_client_bitrate_limit
        if authentication_provider_id is not None:
            self.authentication_provider_id = authentication_provider_id
        if excluded_sub_folders is not None:
            self.excluded_sub_folders = excluded_sub_folders
        if simultaneous_stream_limit is not None:
            self.simultaneous_stream_limit = simultaneous_stream_limit
        if enabled_devices is not None:
            self.enabled_devices = enabled_devices
        if enable_all_devices is not None:
            self.enable_all_devices = enable_all_devices
        if allow_camera_upload is not None:
            self.allow_camera_upload = allow_camera_upload
        if allow_sharing_personal_items is not None:
            self.allow_sharing_personal_items = allow_sharing_personal_items

    @property
    def is_administrator(self):
        """Gets the is_administrator of this UserPolicy.  # noqa: E501

        A value indicating whether this instance is administrator.  # noqa: E501

        :return: The is_administrator of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_administrator

    @is_administrator.setter
    def is_administrator(self, is_administrator):
        """Sets the is_administrator of this UserPolicy.

        A value indicating whether this instance is administrator.  # noqa: E501

        :param is_administrator: The is_administrator of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_administrator = is_administrator

    @property
    def is_hidden(self):
        """Gets the is_hidden of this UserPolicy.  # noqa: E501

        A value indicating whether this instance is hidden.  # noqa: E501

        :return: The is_hidden of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this UserPolicy.

        A value indicating whether this instance is hidden.  # noqa: E501

        :param is_hidden: The is_hidden of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_hidden_remotely(self):
        """Gets the is_hidden_remotely of this UserPolicy.  # noqa: E501


        :return: The is_hidden_remotely of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden_remotely

    @is_hidden_remotely.setter
    def is_hidden_remotely(self, is_hidden_remotely):
        """Sets the is_hidden_remotely of this UserPolicy.


        :param is_hidden_remotely: The is_hidden_remotely of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_hidden_remotely = is_hidden_remotely

    @property
    def is_hidden_from_unused_devices(self):
        """Gets the is_hidden_from_unused_devices of this UserPolicy.  # noqa: E501


        :return: The is_hidden_from_unused_devices of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden_from_unused_devices

    @is_hidden_from_unused_devices.setter
    def is_hidden_from_unused_devices(self, is_hidden_from_unused_devices):
        """Sets the is_hidden_from_unused_devices of this UserPolicy.


        :param is_hidden_from_unused_devices: The is_hidden_from_unused_devices of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_hidden_from_unused_devices = is_hidden_from_unused_devices

    @property
    def is_disabled(self):
        """Gets the is_disabled of this UserPolicy.  # noqa: E501

        A value indicating whether this instance is disabled.  # noqa: E501

        :return: The is_disabled of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_disabled

    @is_disabled.setter
    def is_disabled(self, is_disabled):
        """Sets the is_disabled of this UserPolicy.

        A value indicating whether this instance is disabled.  # noqa: E501

        :param is_disabled: The is_disabled of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_disabled = is_disabled

    @property
    def locked_out_date(self):
        """Gets the locked_out_date of this UserPolicy.  # noqa: E501


        :return: The locked_out_date of this UserPolicy.  # noqa: E501
        :rtype: int
        """
        return self._locked_out_date

    @locked_out_date.setter
    def locked_out_date(self, locked_out_date):
        """Sets the locked_out_date of this UserPolicy.


        :param locked_out_date: The locked_out_date of this UserPolicy.  # noqa: E501
        :type: int
        """

        self._locked_out_date = locked_out_date

    @property
    def max_parental_rating(self):
        """Gets the max_parental_rating of this UserPolicy.  # noqa: E501

        The max parental rating.  # noqa: E501

        :return: The max_parental_rating of this UserPolicy.  # noqa: E501
        :rtype: int
        """
        return self._max_parental_rating

    @max_parental_rating.setter
    def max_parental_rating(self, max_parental_rating):
        """Sets the max_parental_rating of this UserPolicy.

        The max parental rating.  # noqa: E501

        :param max_parental_rating: The max_parental_rating of this UserPolicy.  # noqa: E501
        :type: int
        """

        self._max_parental_rating = max_parental_rating

    @property
    def allow_tag_or_rating(self):
        """Gets the allow_tag_or_rating of this UserPolicy.  # noqa: E501


        :return: The allow_tag_or_rating of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._allow_tag_or_rating

    @allow_tag_or_rating.setter
    def allow_tag_or_rating(self, allow_tag_or_rating):
        """Sets the allow_tag_or_rating of this UserPolicy.


        :param allow_tag_or_rating: The allow_tag_or_rating of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._allow_tag_or_rating = allow_tag_or_rating

    @property
    def blocked_tags(self):
        """Gets the blocked_tags of this UserPolicy.  # noqa: E501


        :return: The blocked_tags of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._blocked_tags

    @blocked_tags.setter
    def blocked_tags(self, blocked_tags):
        """Sets the blocked_tags of this UserPolicy.


        :param blocked_tags: The blocked_tags of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._blocked_tags = blocked_tags

    @property
    def is_tag_blocking_mode_inclusive(self):
        """Gets the is_tag_blocking_mode_inclusive of this UserPolicy.  # noqa: E501


        :return: The is_tag_blocking_mode_inclusive of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._is_tag_blocking_mode_inclusive

    @is_tag_blocking_mode_inclusive.setter
    def is_tag_blocking_mode_inclusive(self, is_tag_blocking_mode_inclusive):
        """Sets the is_tag_blocking_mode_inclusive of this UserPolicy.


        :param is_tag_blocking_mode_inclusive: The is_tag_blocking_mode_inclusive of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._is_tag_blocking_mode_inclusive = is_tag_blocking_mode_inclusive

    @property
    def include_tags(self):
        """Gets the include_tags of this UserPolicy.  # noqa: E501


        :return: The include_tags of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._include_tags

    @include_tags.setter
    def include_tags(self, include_tags):
        """Sets the include_tags of this UserPolicy.


        :param include_tags: The include_tags of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._include_tags = include_tags

    @property
    def enable_user_preference_access(self):
        """Gets the enable_user_preference_access of this UserPolicy.  # noqa: E501


        :return: The enable_user_preference_access of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_user_preference_access

    @enable_user_preference_access.setter
    def enable_user_preference_access(self, enable_user_preference_access):
        """Sets the enable_user_preference_access of this UserPolicy.


        :param enable_user_preference_access: The enable_user_preference_access of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_user_preference_access = enable_user_preference_access

    @property
    def access_schedules(self):
        """Gets the access_schedules of this UserPolicy.  # noqa: E501


        :return: The access_schedules of this UserPolicy.  # noqa: E501
        :rtype: list[AccessSchedule]
        """
        return self._access_schedules

    @access_schedules.setter
    def access_schedules(self, access_schedules):
        """Sets the access_schedules of this UserPolicy.


        :param access_schedules: The access_schedules of this UserPolicy.  # noqa: E501
        :type: list[AccessSchedule]
        """

        self._access_schedules = access_schedules

    @property
    def block_unrated_items(self):
        """Gets the block_unrated_items of this UserPolicy.  # noqa: E501


        :return: The block_unrated_items of this UserPolicy.  # noqa: E501
        :rtype: list[UnratedItem]
        """
        return self._block_unrated_items

    @block_unrated_items.setter
    def block_unrated_items(self, block_unrated_items):
        """Sets the block_unrated_items of this UserPolicy.


        :param block_unrated_items: The block_unrated_items of this UserPolicy.  # noqa: E501
        :type: list[UnratedItem]
        """

        self._block_unrated_items = block_unrated_items

    @property
    def enable_remote_control_of_other_users(self):
        """Gets the enable_remote_control_of_other_users of this UserPolicy.  # noqa: E501


        :return: The enable_remote_control_of_other_users of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_remote_control_of_other_users

    @enable_remote_control_of_other_users.setter
    def enable_remote_control_of_other_users(self, enable_remote_control_of_other_users):
        """Sets the enable_remote_control_of_other_users of this UserPolicy.


        :param enable_remote_control_of_other_users: The enable_remote_control_of_other_users of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_remote_control_of_other_users = enable_remote_control_of_other_users

    @property
    def enable_shared_device_control(self):
        """Gets the enable_shared_device_control of this UserPolicy.  # noqa: E501


        :return: The enable_shared_device_control of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_shared_device_control

    @enable_shared_device_control.setter
    def enable_shared_device_control(self, enable_shared_device_control):
        """Sets the enable_shared_device_control of this UserPolicy.


        :param enable_shared_device_control: The enable_shared_device_control of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_shared_device_control = enable_shared_device_control

    @property
    def enable_remote_access(self):
        """Gets the enable_remote_access of this UserPolicy.  # noqa: E501


        :return: The enable_remote_access of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_remote_access

    @enable_remote_access.setter
    def enable_remote_access(self, enable_remote_access):
        """Sets the enable_remote_access of this UserPolicy.


        :param enable_remote_access: The enable_remote_access of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_remote_access = enable_remote_access

    @property
    def enable_live_tv_management(self):
        """Gets the enable_live_tv_management of this UserPolicy.  # noqa: E501


        :return: The enable_live_tv_management of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_live_tv_management

    @enable_live_tv_management.setter
    def enable_live_tv_management(self, enable_live_tv_management):
        """Sets the enable_live_tv_management of this UserPolicy.


        :param enable_live_tv_management: The enable_live_tv_management of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_live_tv_management = enable_live_tv_management

    @property
    def enable_live_tv_access(self):
        """Gets the enable_live_tv_access of this UserPolicy.  # noqa: E501


        :return: The enable_live_tv_access of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_live_tv_access

    @enable_live_tv_access.setter
    def enable_live_tv_access(self, enable_live_tv_access):
        """Sets the enable_live_tv_access of this UserPolicy.


        :param enable_live_tv_access: The enable_live_tv_access of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_live_tv_access = enable_live_tv_access

    @property
    def enable_media_playback(self):
        """Gets the enable_media_playback of this UserPolicy.  # noqa: E501


        :return: The enable_media_playback of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_media_playback

    @enable_media_playback.setter
    def enable_media_playback(self, enable_media_playback):
        """Sets the enable_media_playback of this UserPolicy.


        :param enable_media_playback: The enable_media_playback of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_media_playback = enable_media_playback

    @property
    def enable_audio_playback_transcoding(self):
        """Gets the enable_audio_playback_transcoding of this UserPolicy.  # noqa: E501


        :return: The enable_audio_playback_transcoding of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_audio_playback_transcoding

    @enable_audio_playback_transcoding.setter
    def enable_audio_playback_transcoding(self, enable_audio_playback_transcoding):
        """Sets the enable_audio_playback_transcoding of this UserPolicy.


        :param enable_audio_playback_transcoding: The enable_audio_playback_transcoding of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_audio_playback_transcoding = enable_audio_playback_transcoding

    @property
    def enable_video_playback_transcoding(self):
        """Gets the enable_video_playback_transcoding of this UserPolicy.  # noqa: E501


        :return: The enable_video_playback_transcoding of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_video_playback_transcoding

    @enable_video_playback_transcoding.setter
    def enable_video_playback_transcoding(self, enable_video_playback_transcoding):
        """Sets the enable_video_playback_transcoding of this UserPolicy.


        :param enable_video_playback_transcoding: The enable_video_playback_transcoding of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_video_playback_transcoding = enable_video_playback_transcoding

    @property
    def enable_playback_remuxing(self):
        """Gets the enable_playback_remuxing of this UserPolicy.  # noqa: E501


        :return: The enable_playback_remuxing of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_playback_remuxing

    @enable_playback_remuxing.setter
    def enable_playback_remuxing(self, enable_playback_remuxing):
        """Sets the enable_playback_remuxing of this UserPolicy.


        :param enable_playback_remuxing: The enable_playback_remuxing of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_playback_remuxing = enable_playback_remuxing

    @property
    def enable_content_deletion(self):
        """Gets the enable_content_deletion of this UserPolicy.  # noqa: E501


        :return: The enable_content_deletion of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_content_deletion

    @enable_content_deletion.setter
    def enable_content_deletion(self, enable_content_deletion):
        """Sets the enable_content_deletion of this UserPolicy.


        :param enable_content_deletion: The enable_content_deletion of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_content_deletion = enable_content_deletion

    @property
    def restricted_features(self):
        """Gets the restricted_features of this UserPolicy.  # noqa: E501


        :return: The restricted_features of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._restricted_features

    @restricted_features.setter
    def restricted_features(self, restricted_features):
        """Sets the restricted_features of this UserPolicy.


        :param restricted_features: The restricted_features of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._restricted_features = restricted_features

    @property
    def enable_content_deletion_from_folders(self):
        """Gets the enable_content_deletion_from_folders of this UserPolicy.  # noqa: E501


        :return: The enable_content_deletion_from_folders of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._enable_content_deletion_from_folders

    @enable_content_deletion_from_folders.setter
    def enable_content_deletion_from_folders(self, enable_content_deletion_from_folders):
        """Sets the enable_content_deletion_from_folders of this UserPolicy.


        :param enable_content_deletion_from_folders: The enable_content_deletion_from_folders of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._enable_content_deletion_from_folders = enable_content_deletion_from_folders

    @property
    def enable_content_downloading(self):
        """Gets the enable_content_downloading of this UserPolicy.  # noqa: E501


        :return: The enable_content_downloading of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_content_downloading

    @enable_content_downloading.setter
    def enable_content_downloading(self, enable_content_downloading):
        """Sets the enable_content_downloading of this UserPolicy.


        :param enable_content_downloading: The enable_content_downloading of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_content_downloading = enable_content_downloading

    @property
    def enable_subtitle_downloading(self):
        """Gets the enable_subtitle_downloading of this UserPolicy.  # noqa: E501


        :return: The enable_subtitle_downloading of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_subtitle_downloading

    @enable_subtitle_downloading.setter
    def enable_subtitle_downloading(self, enable_subtitle_downloading):
        """Sets the enable_subtitle_downloading of this UserPolicy.


        :param enable_subtitle_downloading: The enable_subtitle_downloading of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_subtitle_downloading = enable_subtitle_downloading

    @property
    def enable_subtitle_management(self):
        """Gets the enable_subtitle_management of this UserPolicy.  # noqa: E501


        :return: The enable_subtitle_management of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_subtitle_management

    @enable_subtitle_management.setter
    def enable_subtitle_management(self, enable_subtitle_management):
        """Sets the enable_subtitle_management of this UserPolicy.


        :param enable_subtitle_management: The enable_subtitle_management of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_subtitle_management = enable_subtitle_management

    @property
    def enable_sync_transcoding(self):
        """Gets the enable_sync_transcoding of this UserPolicy.  # noqa: E501

        A value indicating whether \\[enable synchronize\\].  # noqa: E501

        :return: The enable_sync_transcoding of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_sync_transcoding

    @enable_sync_transcoding.setter
    def enable_sync_transcoding(self, enable_sync_transcoding):
        """Sets the enable_sync_transcoding of this UserPolicy.

        A value indicating whether \\[enable synchronize\\].  # noqa: E501

        :param enable_sync_transcoding: The enable_sync_transcoding of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_sync_transcoding = enable_sync_transcoding

    @property
    def enable_media_conversion(self):
        """Gets the enable_media_conversion of this UserPolicy.  # noqa: E501


        :return: The enable_media_conversion of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_media_conversion

    @enable_media_conversion.setter
    def enable_media_conversion(self, enable_media_conversion):
        """Sets the enable_media_conversion of this UserPolicy.


        :param enable_media_conversion: The enable_media_conversion of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_media_conversion = enable_media_conversion

    @property
    def enabled_channels(self):
        """Gets the enabled_channels of this UserPolicy.  # noqa: E501


        :return: The enabled_channels of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._enabled_channels

    @enabled_channels.setter
    def enabled_channels(self, enabled_channels):
        """Sets the enabled_channels of this UserPolicy.


        :param enabled_channels: The enabled_channels of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._enabled_channels = enabled_channels

    @property
    def enable_all_channels(self):
        """Gets the enable_all_channels of this UserPolicy.  # noqa: E501


        :return: The enable_all_channels of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_all_channels

    @enable_all_channels.setter
    def enable_all_channels(self, enable_all_channels):
        """Sets the enable_all_channels of this UserPolicy.


        :param enable_all_channels: The enable_all_channels of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_all_channels = enable_all_channels

    @property
    def enabled_folders(self):
        """Gets the enabled_folders of this UserPolicy.  # noqa: E501


        :return: The enabled_folders of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._enabled_folders

    @enabled_folders.setter
    def enabled_folders(self, enabled_folders):
        """Sets the enabled_folders of this UserPolicy.


        :param enabled_folders: The enabled_folders of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._enabled_folders = enabled_folders

    @property
    def enable_all_folders(self):
        """Gets the enable_all_folders of this UserPolicy.  # noqa: E501


        :return: The enable_all_folders of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_all_folders

    @enable_all_folders.setter
    def enable_all_folders(self, enable_all_folders):
        """Sets the enable_all_folders of this UserPolicy.


        :param enable_all_folders: The enable_all_folders of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_all_folders = enable_all_folders

    @property
    def invalid_login_attempt_count(self):
        """Gets the invalid_login_attempt_count of this UserPolicy.  # noqa: E501


        :return: The invalid_login_attempt_count of this UserPolicy.  # noqa: E501
        :rtype: int
        """
        return self._invalid_login_attempt_count

    @invalid_login_attempt_count.setter
    def invalid_login_attempt_count(self, invalid_login_attempt_count):
        """Sets the invalid_login_attempt_count of this UserPolicy.


        :param invalid_login_attempt_count: The invalid_login_attempt_count of this UserPolicy.  # noqa: E501
        :type: int
        """

        self._invalid_login_attempt_count = invalid_login_attempt_count

    @property
    def enable_public_sharing(self):
        """Gets the enable_public_sharing of this UserPolicy.  # noqa: E501


        :return: The enable_public_sharing of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_public_sharing

    @enable_public_sharing.setter
    def enable_public_sharing(self, enable_public_sharing):
        """Sets the enable_public_sharing of this UserPolicy.


        :param enable_public_sharing: The enable_public_sharing of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_public_sharing = enable_public_sharing

    @property
    def blocked_media_folders(self):
        """Gets the blocked_media_folders of this UserPolicy.  # noqa: E501


        :return: The blocked_media_folders of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._blocked_media_folders

    @blocked_media_folders.setter
    def blocked_media_folders(self, blocked_media_folders):
        """Sets the blocked_media_folders of this UserPolicy.


        :param blocked_media_folders: The blocked_media_folders of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._blocked_media_folders = blocked_media_folders

    @property
    def remote_client_bitrate_limit(self):
        """Gets the remote_client_bitrate_limit of this UserPolicy.  # noqa: E501


        :return: The remote_client_bitrate_limit of this UserPolicy.  # noqa: E501
        :rtype: int
        """
        return self._remote_client_bitrate_limit

    @remote_client_bitrate_limit.setter
    def remote_client_bitrate_limit(self, remote_client_bitrate_limit):
        """Sets the remote_client_bitrate_limit of this UserPolicy.


        :param remote_client_bitrate_limit: The remote_client_bitrate_limit of this UserPolicy.  # noqa: E501
        :type: int
        """

        self._remote_client_bitrate_limit = remote_client_bitrate_limit

    @property
    def authentication_provider_id(self):
        """Gets the authentication_provider_id of this UserPolicy.  # noqa: E501


        :return: The authentication_provider_id of this UserPolicy.  # noqa: E501
        :rtype: str
        """
        return self._authentication_provider_id

    @authentication_provider_id.setter
    def authentication_provider_id(self, authentication_provider_id):
        """Sets the authentication_provider_id of this UserPolicy.


        :param authentication_provider_id: The authentication_provider_id of this UserPolicy.  # noqa: E501
        :type: str
        """

        self._authentication_provider_id = authentication_provider_id

    @property
    def excluded_sub_folders(self):
        """Gets the excluded_sub_folders of this UserPolicy.  # noqa: E501


        :return: The excluded_sub_folders of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._excluded_sub_folders

    @excluded_sub_folders.setter
    def excluded_sub_folders(self, excluded_sub_folders):
        """Sets the excluded_sub_folders of this UserPolicy.


        :param excluded_sub_folders: The excluded_sub_folders of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._excluded_sub_folders = excluded_sub_folders

    @property
    def simultaneous_stream_limit(self):
        """Gets the simultaneous_stream_limit of this UserPolicy.  # noqa: E501


        :return: The simultaneous_stream_limit of this UserPolicy.  # noqa: E501
        :rtype: int
        """
        return self._simultaneous_stream_limit

    @simultaneous_stream_limit.setter
    def simultaneous_stream_limit(self, simultaneous_stream_limit):
        """Sets the simultaneous_stream_limit of this UserPolicy.


        :param simultaneous_stream_limit: The simultaneous_stream_limit of this UserPolicy.  # noqa: E501
        :type: int
        """

        self._simultaneous_stream_limit = simultaneous_stream_limit

    @property
    def enabled_devices(self):
        """Gets the enabled_devices of this UserPolicy.  # noqa: E501


        :return: The enabled_devices of this UserPolicy.  # noqa: E501
        :rtype: list[str]
        """
        return self._enabled_devices

    @enabled_devices.setter
    def enabled_devices(self, enabled_devices):
        """Sets the enabled_devices of this UserPolicy.


        :param enabled_devices: The enabled_devices of this UserPolicy.  # noqa: E501
        :type: list[str]
        """

        self._enabled_devices = enabled_devices

    @property
    def enable_all_devices(self):
        """Gets the enable_all_devices of this UserPolicy.  # noqa: E501


        :return: The enable_all_devices of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._enable_all_devices

    @enable_all_devices.setter
    def enable_all_devices(self, enable_all_devices):
        """Sets the enable_all_devices of this UserPolicy.


        :param enable_all_devices: The enable_all_devices of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._enable_all_devices = enable_all_devices

    @property
    def allow_camera_upload(self):
        """Gets the allow_camera_upload of this UserPolicy.  # noqa: E501


        :return: The allow_camera_upload of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._allow_camera_upload

    @allow_camera_upload.setter
    def allow_camera_upload(self, allow_camera_upload):
        """Sets the allow_camera_upload of this UserPolicy.


        :param allow_camera_upload: The allow_camera_upload of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._allow_camera_upload = allow_camera_upload

    @property
    def allow_sharing_personal_items(self):
        """Gets the allow_sharing_personal_items of this UserPolicy.  # noqa: E501


        :return: The allow_sharing_personal_items of this UserPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._allow_sharing_personal_items

    @allow_sharing_personal_items.setter
    def allow_sharing_personal_items(self, allow_sharing_personal_items):
        """Sets the allow_sharing_personal_items of this UserPolicy.


        :param allow_sharing_personal_items: The allow_sharing_personal_items of this UserPolicy.  # noqa: E501
        :type: bool
        """

        self._allow_sharing_personal_items = allow_sharing_personal_items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
